/* line 5, ../../../vendor/bundle/ruby/2.3.0/gems/compass-core-1.0.3/stylesheets/compass/reset/_utilities.scss */
html, body, div, span, applet, object, iframe,
h1, h2, h3, h4, h5, h6, p, blockquote, pre,
a, abbr, acronym, address, big, cite, code,
del, dfn, em, img, ins, kbd, q, s, samp,
small, strike, strong, sub, sup, tt, var,
b, u, i, center,
dl, dt, dd, ol, ul, li,
fieldset, form, label, legend,
table, caption, tbody, tfoot, thead, tr, th, td,
article, aside, canvas, details, embed,
figure, figcaption, footer, header, hgroup,
menu, nav, output, ruby, section, summary,
time, mark, audio, video {
  margin: 0;
  padding: 0;
  border: 0;
  font: inherit;
  font-size: 100%;
  vertical-align: baseline;
}

/* line 22, ../../../vendor/bundle/ruby/2.3.0/gems/compass-core-1.0.3/stylesheets/compass/reset/_utilities.scss */
html {
  line-height: 1;
}

/* line 24, ../../../vendor/bundle/ruby/2.3.0/gems/compass-core-1.0.3/stylesheets/compass/reset/_utilities.scss */
ol, ul {
  list-style: none;
}

/* line 26, ../../../vendor/bundle/ruby/2.3.0/gems/compass-core-1.0.3/stylesheets/compass/reset/_utilities.scss */
table {
  border-collapse: collapse;
  border-spacing: 0;
}

/* line 28, ../../../vendor/bundle/ruby/2.3.0/gems/compass-core-1.0.3/stylesheets/compass/reset/_utilities.scss */
caption, th, td {
  text-align: left;
  font-weight: normal;
  vertical-align: middle;
}

/* line 30, ../../../vendor/bundle/ruby/2.3.0/gems/compass-core-1.0.3/stylesheets/compass/reset/_utilities.scss */
q, blockquote {
  quotes: none;
}
/* line 103, ../../../vendor/bundle/ruby/2.3.0/gems/compass-core-1.0.3/stylesheets/compass/reset/_utilities.scss */
q:before, q:after, blockquote:before, blockquote:after {
  content: "";
  content: none;
}

/* line 32, ../../../vendor/bundle/ruby/2.3.0/gems/compass-core-1.0.3/stylesheets/compass/reset/_utilities.scss */
a img {
  border: none;
}

/* line 116, ../../../vendor/bundle/ruby/2.3.0/gems/compass-core-1.0.3/stylesheets/compass/reset/_utilities.scss */
article, aside, details, figcaption, figure, footer, header, hgroup, main, menu, nav, section, summary {
  display: block;
}

/* line 1, ../../scss/_reset.scss */
html {
  box-sizing: border-box;
}

/* line 5, ../../scss/_reset.scss */
*,
*::before,
*::after {
  box-sizing: inherit;
}

/* line 11, ../../scss/_reset.scss */
a, input, button {
  outline: none;
}

/* line 15, ../../scss/_reset.scss */
input, button {
  padding: 0;
  border: 0;
  border-radius: 0;
  box-shadow: none;
  font-family: inherit;
}

/* line 23, ../../scss/_reset.scss */
input:-webkit-autofill {
  -webkit-box-shadow: 0 0 0 30px white inset;
}

/* line 1, ../../scss/_base.scss */
body {
  font-family: Roboto, Verdana;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, sans-serif;
  line-height: 1.4;
  background: #f7f7f9;
  color: #292b2c;
}
@media (min-width: 576px) {
  /* line 1, ../../scss/_base.scss */
  body {
    display: flex;
    align-items: center;
    justify-content: center;
  }
}

/* line 16, ../../scss/_base.scss */
a {
  transition: background 0.15s, color 0.15s, border-color 0.15s;
  color: #025aa5;
  font-size: inherit;
  text-decoration: none;
}
/* line 10, ../../scss/_mixins.scss */
a:focus, a:hover {
  text-decoration: underline;
}

/* line 21, ../../scss/_base.scss */
b {
  font-weight: bold;
}

/********************
 * Layout structure *
 ********************/
/* line 32, ../../scss/_base.scss */
.wrapper {
  max-width: 500px;
  margin: 0 auto;
  background: #fff;
  box-shadow: 0 0 5px rgba(0, 0, 0, 0.1);
}

@media (min-height: 400px) and (min-width: 576px) {
  /* line 42, ../../scss/_base.scss */
  html, body {
    height: 100%;
  }
}
@media (min-height: 500px) and (min-width: 576px) {
  /* line 48, ../../scss/_base.scss */
  .wrapper {
    position: relative;
    top: -5%;
  }
}
/* line 54, ../../scss/_base.scss */
.content-wrapper {
  display: flex;
  flex-flow: row wrap;
  align-items: center;
  /* Blocks */
}
/* line 61, ../../scss/_base.scss */
.content-wrapper > section {
  flex: 1 100%;
  padding: 15px;
}
@media (min-width: 500px) {
  /* line 67, ../../scss/_base.scss */
  .content-wrapper > section {
    flex: 1 1 auto;
    width: 250px;
  }
}
@media (min-width: 120px) {
  /* line 74, ../../scss/_base.scss */
  .content-wrapper > section {
    flex: 1 1 auto;
    width: 350px;
  }
}

/* line 82, ../../scss/_base.scss */
#providers {
  width: 150px;
}

/**********
 * Header *
 **********/
/* line 94, ../../scss/_base.scss */
header {
  display: flex;
  align-items: stretch;
  min-height: 55px;
  background: #c9302c;
  color: #fff;
  font-size: 20px;
  font-weight: bold;
}
/* line 18, ../../scss/_mixins.scss */
header::after {
  display: block;
  content: "";
  clear: both;
}
/* line 108, ../../scss/_base.scss */
header a {
  color: #fff !important;
}
/* line 10, ../../scss/_mixins.scss */
header a:focus, header a:hover {
  background: #d43f3a;
  text-decoration: none;
}
/* line 117, ../../scss/_base.scss */
header .right {
  display: flex;
  flex-flow: column;
  align-items: stretch;
  justify-content: space-around;
  flex: 0 0 auto;
  border-left: 1px solid #de6764;
  font-size: 14px;
  text-align: center;
}
/* line 130, ../../scss/_base.scss */
header .right > * {
  flex: 0 0 auto;
}
/* line 133, ../../scss/_base.scss */
header .right > * > * {
  display: block;
  padding: 5px 10px;
}
/* line 139, ../../scss/_base.scss */
header .right #connect-status {
  font-weight: normal;
  font-size: 12px;
}
/* line 143, ../../scss/_base.scss */
header .right #connect-status .fa {
  margin-right: 5px;
}
/* line 149, ../../scss/_base.scss */
header h1 {
  flex: 1 1 auto;
  padding: 15px 25px;
}

/************
 * Messages *
 ************/
/* line 162, ../../scss/_base.scss */
.messages-container {
  padding: 0 15px;
}
/* line 165, ../../scss/_base.scss */
.messages-container::after {
  display: block;
  content: "";
  background-color: #eceeef;
  height: 2px;
}

/* line 173, ../../scss/_base.scss */
.messages-list {
  padding: 10px 0;
}

/* line 183, ../../scss/_base.scss */
.message {
  padding: 5px;
  font-size: 14px;
  color: #292b2c;
}
/* line 178, ../../scss/_base.scss */
.message.info {
  color: #28a1c5;
}
/* line 178, ../../scss/_base.scss */
.message.success {
  color: #2d672d;
}
/* line 178, ../../scss/_base.scss */
.message.warning {
  color: #b06d0f;
}
/* line 178, ../../scss/_base.scss */
.message.error {
  color: #b52b27;
}

/***********
 * Content *
 ***********/
/* line 202, ../../scss/_base.scss */
section > * + * {
  margin-top: 15px;
}

/* Methods list */
/* line 210, ../../scss/_base.scss */
.method-list {
  display: flex;
  flex-flow: row wrap;
  justify-content: space-between;
}
/* line 215, ../../scss/_base.scss */
.method-list > .method-wrapper {
  flex: 1 100%;
  padding: 2px 0;
}
/* line 219, ../../scss/_base.scss */
.method-list > .method-wrapper a {
  transition: background 0.15s, color 0.15s, border-color 0.15s;
  display: block;
  width: 100%;
  min-height: 30px;
  line-height: initial;
  border: 0;
  border-radius: 3px;
  padding: 7px 15px;
  font-size: 18px;
  text-align: center;
  border-radius: 0;
  border-left: 5px solid #025aa5;
  background: #eceeef;
  color: #000;
  font-size: 16px;
  text-align: left;
}
/* line 10, ../../scss/_mixins.scss */
.method-list > .method-wrapper a:focus, .method-list > .method-wrapper a:hover {
  text-decoration: none;
  cursor: pointer;
}
/* line 10, ../../scss/_mixins.scss */
.method-list > .method-wrapper a:focus, .method-list > .method-wrapper a:hover {
  background: #a8d6fe;
}

/* Connected accounts list */
/* line 243, ../../scss/_base.scss */
.connections-providers-list > * + * {
  margin-top: 2px;
}
/* line 247, ../../scss/_base.scss */
.connections-providers-list > * > .heading {
  width: 100%;
  padding: 10px;
  border-left: 5px solid #025aa5;
  background: #eceeef;
}
/* line 18, ../../scss/_mixins.scss */
.connections-providers-list > * > .heading::after {
  display: block;
  content: "";
  clear: both;
}
/* line 256, ../../scss/_base.scss */
.connections-providers-list > * > .heading .connect {
  transition: background 0.15s, color 0.15s, border-color 0.15s;
  display: block;
  width: 100%;
  min-height: 30px;
  line-height: initial;
  border: 0;
  border-radius: 3px;
  padding: 7px 15px;
  font-size: 18px;
  text-align: center;
  background: #025aa5;
  color: #fff;
  min-height: auto;
  padding: 4px 7px;
  font-size: 12px;
  float: right;
  width: auto;
}
/* line 10, ../../scss/_mixins.scss */
.connections-providers-list > * > .heading .connect:focus, .connections-providers-list > * > .heading .connect:hover {
  text-decoration: none;
  cursor: pointer;
}
/* line 10, ../../scss/_mixins.scss */
.connections-providers-list > * > .heading .connect:focus, .connections-providers-list > * > .heading .connect:hover {
  background: #014c8c;
  color: #fff;
}

/* line 268, ../../scss/_base.scss */
.connections-list {
  border-left: 5px solid #f7f7f9;
}
/* line 271, ../../scss/_base.scss */
.connections-list > * {
  padding: 10px;
  font-size: 14px;
}
/* line 275, ../../scss/_base.scss */
.connections-list > * + * {
  border-top: 1px dotted #eceeef;
}
/* line 279, ../../scss/_base.scss */
.connections-list > * > .fa {
  margin-right: 5px;
}
/* line 283, ../../scss/_base.scss */
.connections-list > * .delete {
  float: right;
  margin-top: -2px;
}
/* line 287, ../../scss/_base.scss */
.connections-list > * .delete [type=submit] {
  transition: background 0.15s, color 0.15s, border-color 0.15s;
  display: block;
  width: 100%;
  min-height: 30px;
  line-height: initial;
  border: 0;
  border-radius: 3px;
  padding: 7px 15px;
  font-size: 18px;
  text-align: center;
  background: #d9534f;
  color: #fff;
  min-height: auto;
  padding: 4px 7px;
  font-size: 12px;
  opacity: .8;
}
/* line 10, ../../scss/_mixins.scss */
.connections-list > * .delete [type=submit]:focus, .connections-list > * .delete [type=submit]:hover {
  text-decoration: none;
  cursor: pointer;
}
/* line 10, ../../scss/_mixins.scss */
.connections-list > * .delete [type=submit]:focus, .connections-list > * .delete [type=submit]:hover {
  background: #b52b27;
  color: #fff;
}
/* line 296, ../../scss/_base.scss */
.connections-list form {
  display: inline-block;
}

/* E-mail adresses list */
/* line 305, ../../scss/_base.scss */
.emailaddress-list .emailaddress {
  border-bottom: 1px dotted #464a4c;
}
/* line 309, ../../scss/_base.scss */
.emailaddress-list .emailaddress .summary {
  height: 45px;
}
/* line 18, ../../scss/_mixins.scss */
.emailaddress-list .emailaddress .summary::after {
  display: block;
  content: "";
  clear: both;
}
/* line 314, ../../scss/_base.scss */
.emailaddress-list .emailaddress .summary > * {
  float: left;
  height: 100%;
  padding: 12px;
}
/* line 320, ../../scss/_base.scss */
.emailaddress-list .emailaddress .summary > .primary, .emailaddress-list .emailaddress .summary > .verified-status {
  float: right;
  width: 45px;
  line-height: 100%;
  text-align: center;
  font-size: 20px;
}
/* line 328, ../../scss/_base.scss */
.emailaddress-list .emailaddress .summary > .email {
  padding: 12px;
  font-weight: bold;
}
/* line 333, ../../scss/_base.scss */
.emailaddress-list .emailaddress .summary > .primary {
  color: #025aa5;
}
/* line 337, ../../scss/_base.scss */
.emailaddress-list .emailaddress .summary > .verified {
  color: #449d44;
}
/* line 341, ../../scss/_base.scss */
.emailaddress-list .emailaddress .summary > .unverified {
  color: #ec971f;
}

/* line 350, ../../scss/_base.scss */
.actions {
  margin-bottom: 10px;
}
/* line 18, ../../scss/_mixins.scss */
.actions::after {
  display: block;
  content: "";
  clear: both;
}
/* line 355, ../../scss/_base.scss */
.actions > * {
  float: right;
  margin-right: 10px;
  font-size: 12px;
}

/*********
 * Forms *
 *********/
/* line 387, ../../scss/_base.scss */
.input-wrapper {
  position: relative;
  display: block;
  margin: 19.5px 0;
  padding: 0;
}
/* line 18, ../../scss/_mixins.scss */
.input-wrapper::after {
  display: block;
  content: "";
  clear: both;
}
/* line 395, ../../scss/_base.scss */
.input-wrapper label {
  padding-left: 0;
  width: 100%;
  max-width: 100%;
  height: 26px;
  line-height: 26px;
  color: rgba(0, 0, 0, 0.38);
  font-size: 16px;
}
/* line 26, ../../scss/_mixins.scss */
.input-wrapper label {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
/* line 410, ../../scss/_base.scss */
.input-wrapper:not(.input-skip) label {
  position: absolute;
  bottom: 100%;
  left: 0;
  pointer-events: none;
  transform: translate3d(0, 28px, 0) scale(1);
  transition: transform 0.4s cubic-bezier(0.25, 0.8, 0.25, 1);
  transform-origin: left top;
}
/* line 422, ../../scss/_base.scss */
.input-wrapper input.field:not([type=checkbox]) {
  height: 30px;
  width: 100%;
  padding: 2px 2px 1px;
  background-color: #fff;
  line-height: 26px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  font-size: 16px;
}
/* line 436, ../../scss/_base.scss */
.input-wrapper input[type="checkbox"] {
  vertical-align: sub;
  width: 20px;
  height: 20px;
}
/* line 456, ../../scss/_base.scss */
.input-wrapper:not(.input-skip).input-focused label, .input-wrapper:not(.input-skip).input-has-value label {
  transform: translate3d(0, 6.5px, 0) scale(0.75);
}
/* line 461, ../../scss/_base.scss */
.input-wrapper:not(.input-skip).input-focused label {
  color: inherit;
}
/* line 443, ../../scss/_base.scss */
.input-wrapper.input-has-value {
  color: #449d44;
}
/* line 447, ../../scss/_base.scss */
.input-wrapper.input-has-value input.field {
  padding-bottom: 0px;
  border-width: 2px;
  border-color: #449d44;
}
/* line 443, ../../scss/_base.scss */
.input-wrapper.input-error {
  color: #d9534f;
}
/* line 447, ../../scss/_base.scss */
.input-wrapper.input-error input.field {
  padding-bottom: 0px;
  border-width: 2px;
  border-color: #d9534f;
}
/* line 443, ../../scss/_base.scss */
.input-wrapper.input-focused {
  color: #025aa5;
}
/* line 447, ../../scss/_base.scss */
.input-wrapper.input-focused input.field {
  padding-bottom: 0px;
  border-width: 2px;
  border-color: #025aa5;
}
/* line 470, ../../scss/_base.scss */
.input-wrapper .infos-spacer {
  float: right;
  min-height: 10px;
  min-width: 1px;
}
/* line 478, ../../scss/_base.scss */
.input-wrapper .messages > * {
  padding-top: 5px;
  font-size: 12px;
}

/* line 486, ../../scss/_base.scss */
.widget-checkbox {
  display: inline-flex;
}
/* line 489, ../../scss/_base.scss */
.widget-checkbox > input[type="checkbox"] {
  display: none;
}
/* line 493, ../../scss/_base.scss */
.widget-checkbox > button {
  transition: background 0.15s, color 0.15s, border-color 0.15s;
  flex: 0 1 auto;
  display: inline-block;
  padding: 5px 10px;
  background: white;
  color: #636c72;
}
/* line 502, ../../scss/_base.scss */
.widget-checkbox > button.choice-yes {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
}
/* line 507, ../../scss/_base.scss */
.widget-checkbox > button.choice-no {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
}
/* line 512, ../../scss/_base.scss */
.widget-checkbox > button.focus {
  background: #025aa5;
  color: white;
}

/* line 518, ../../scss/_base.scss */
[type=submit]:not(.link) {
  transition: background 0.15s, color 0.15s, border-color 0.15s;
  display: block;
  width: 100%;
  min-height: 30px;
  line-height: initial;
  border: 0;
  border-radius: 3px;
  padding: 7px 15px;
  font-size: 18px;
  text-align: center;
  background: #449d44;
  color: #fff;
  border-radius: 3px;
}
/* line 10, ../../scss/_mixins.scss */
[type=submit]:not(.link):focus, [type=submit]:not(.link):hover {
  text-decoration: none;
  cursor: pointer;
}
/* line 10, ../../scss/_mixins.scss */
[type=submit]:not(.link):focus, [type=submit]:not(.link):hover {
  background: #2d672d;
  color: #fff;
}

/* line 524, ../../scss/_base.scss */
[type=submit].link {
  transition: background 0.15s, color 0.15s, border-color 0.15s;
  color: #025aa5;
  font-size: inherit;
  text-decoration: none;
  background: transparent;
}
/* line 10, ../../scss/_mixins.scss */
[type=submit].link:focus, [type=submit].link:hover {
  text-decoration: underline;
}
/* line 10, ../../scss/_mixins.scss */
[type=submit].link:focus, [type=submit].link:hover {
  cursor: pointer;
}

/* line 533, ../../scss/_base.scss */
.form-inline {
  display: flex;
  align-items: center;
}
/* line 537, ../../scss/_base.scss */
.form-inline > .input-wrapper {
  flex: 1 0 auto;
}
/* line 541, ../../scss/_base.scss */
.form-inline [type=submit] {
  margin-top: -5px;
  margin-left: 8px;
  font-size: 14px;
}

/* line 548, ../../scss/_base.scss */
.btn {
  transition: background 0.15s, color 0.15s, border-color 0.15s;
  display: block;
  width: 100%;
  min-height: 30px;
  line-height: initial;
  border: 0;
  border-radius: 3px;
  padding: 7px 15px;
  font-size: 18px;
  text-align: center;
  display: block;
}
/* line 10, ../../scss/_mixins.scss */
.btn:focus, .btn:hover {
  text-decoration: none;
  cursor: pointer;
}

/* line 553, ../../scss/_base.scss */
.btn-primary {
  background: #025aa5;
  color: #fff;
}
/* line 10, ../../scss/_mixins.scss */
.btn-primary:focus, .btn-primary:hover {
  background: #014c8c;
  color: #fff;
}

/* line 554, ../../scss/_base.scss */
.btn-success {
  background: #449d44;
  color: #fff;
}
/* line 10, ../../scss/_mixins.scss */
.btn-success:focus, .btn-success:hover {
  background: #2d672d;
  color: #fff;
}
