{% extends "allauth_ens/base.html" %}
{% load i18n %}

{% block title %}{% trans "Set Password" %}{% endblock %}
{% block header-title %}{% trans "Set Password" %}{% endblock %}

{% block messages-extra %}

{% include "allauth_ens/block-messages-form-errors.html" with form_errors=form.non_field_errors %}

{% endblock %}

{% block content %}

<section>
  <p>
    {% blocktrans %}
    Your account does not have a password yet. Add one to authenticate without
    third parties.
    {% endblocktrans %}
  </p>
  <form action="{% url "account_set_password" %}" method="post">
    {% include "allauth_ens/block-form.html" with form=form %}
    <input type="submit" value="{% trans "Set Password" %}">
  </form>
</section>

{% endblock %}
