{% extends "allauth_ens/base.html" %}
{% load i18n %}

{% block title %}{% trans "Change Password" %}{% endblock %}
{% block header-title %}{% trans "Change Password" %}{% endblock %}

{% block content %}

<section>
  <p>
    {% blocktrans %}
    Your password is now changed.
    {% endblocktrans %}
  </p>
</section>

{% endblock %}
